@@ -17,15 +17,14 @@ class Postfix(monasca_setup.detection.Plugin):
         """
         if monasca_setup.detection.find_process_cmdline('postfix') is not None:
             # Test for sudo access
-            # TODO(craig): don't hardcode the user. Need to get it from the arguments to monasca_setup
+            # TODO: don't hardcode the user. Need to get it from the arguments to monasca_setup
             test_sudo = os.system('sudo -l -U mon-agent find /var/spool/postfix/incoming -type f > /dev/null')
             if test_sudo != 0:
                 log.info("Postfix found but the required sudo access is not configured.\n\t" +
                          "Refer to plugin documentation for more detail")
                 return False
-            self.available = True
-        else:
-            self.available = False
+
+        self.available = True
 
     def build_config(self):
         """Build the config as a Plugins object and return.
